@@ -1,4 +1,4 @@
-'V1.13.02'
+'V1.15'
 '''Change Log
 new function - common
 V1.13.00
@@ -13,12 +13,14 @@ __all__ = [
     'B','Blank','BB','bbfy','C','choose','common','crop_from_bb','cv2', 'dumpdill','df2bbs','diff','find',
     'flatten','fname','find','fname2','glob','Glob','inspect','jitter', 'L',
     'line','loaddill','logger','extn', 'makedir', 'np', 'now','nunique','os','pd','pdfilter','parent','Path','pdb',
-    'plt','PIL','puttext','randint','rand','read','rect','rename_batch','resize','see','set_logging_level','show','stem',
-    'stems','subplots','sys','tqdm','Tqdm','Timer','unique','uint'
+    'plt','PIL','puttext','randint','rand','read','readlines','readPIL','rect','rename_batch','resize','see',
+    'set_logging_level','show','stem','stems','subplots','sys','tqdm','Tqdm','Timer','unique','uint',
+    'Info','Warn','Debug','Excep'
 ]
 
 import cv2, glob, numpy as np, pandas as pd, tqdm, os, sys
 import PIL
+from PIL import Image
 try:
     import torch
     import torch.nn as nn
@@ -42,6 +44,11 @@ except:
         def warning(self, message): print(f'WARNING:\t{message}')
         def exception(self, message): print(f'EXCEPTION:\t{message}')
     logger = Logger()
+Info  = lambda x: logger.info(x)
+Warn  = lambda x: logger.warning(x)
+Debug = lambda x: logger.debug(x)
+Excep = lambda x: logger.exception(x)
+
 import time
 class Timer:
     def __init__(self, N):
@@ -125,6 +132,11 @@ def read(fname, mode=0):
     img = cv2.imread(str(fname), mode)
     if mode == 1: img = img[...,::-1] # BGR to RGB
     return img
+
+def readPIL(fname, mode='RGB'):
+    if mode.lower() == 'bw': mode = 'L'
+    return Image.open(str(fname)).convert(mode.upper())
+
 def crop_from_bb(im, bb):
     x,y,X,Y = bb
     return im.copy()[y:Y,x:X]
@@ -203,7 +215,7 @@ def show(img=None, ax=None, title=None, sz=None, bbs=None, confs=None,
     'show an image'
     try:
         if isinstance(img, torch.Tensor): img = img.cpu().detach().numpy().copy()
-        if isinstance(img, PIL.Image): img = np.array(img)
+        if isinstance(img, PIL.Image.Image): img = np.array(img)
     except: ...
     if len(img.shape) == 3 and len(img) == 3:
         # this is likely a torch tensor
@@ -392,6 +404,12 @@ def resize(im:np.ndarray, sz:[float,('H','W')]):
             H,W = sz
     return cv2.resize(im, (W,H))
 
+def readlines(fpath):
+    with open(fpath, 'r') as f:
+        lines = f.read().split('\n')
+        lines = [l.strip() for l in lines if l.strip()!='']
+        Info(f'loaded {len(lines)} lines')
+        return lines
 '''108 ways to orgasm
 * Walk on soil
 * Drink clean water, eyes closed and sitting
